package com.tencent.qcloud.rntimpush;

import android.content.Context;
import android.util.Log;

import androidx.annotation.NonNull;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.module.annotations.ReactModule;

import com.tencent.qcloud.tim.push.TIMPushManager;
import com.tencent.qcloud.tim.push.TIMPushCallback;
import com.tencent.qcloud.tim.push.config.TIMPushConfig;

import com.facebook.react.bridge.Callback;

@ReactModule(name = TencentCloudPushModule.NAME)
public class TencentCloudPushModule extends ReactContextBaseJavaModule {
  private Context mContext;
  private String mExtInfo = "";
  private String LOG_PREFIX = "Push java |";
  public static final String NAME = "TencentCloudPush";

  public static TencentCloudPushModule instance;

  public static ReactApplicationContext rContext;

  public TencentCloudPushModule(ReactApplicationContext reactContext) {
    super(reactContext);
    rContext = reactContext;
    mContext = reactContext.getApplicationContext();
    instance = this;
  }

  @Override
  @NonNull
  public String getName() {
    return NAME;
  }

  @ReactMethod
  public void registerPush(int SDKAppID, String appKey, Callback onSucc) {
    Log.i(NAME, LOG_PREFIX + " registerPush | " + SDKAppID + " " + appKey);
    setRunningPlatform();
    TIMPushManager.getInstance().registerPush(mContext, SDKAppID, appKey, new TIMPushCallback() {
        @Override
        public void onSuccess(Object data) {
          onSucc.invoke(data);
          if (data != null) {
            String token = (String)data;
            Log.i(NAME, LOG_PREFIX + " registerPush ok | " + token);
          }
        }
        
        @Override    
        public void onError(int errCode, String errMsg, Object data) { 
          Log.i(NAME, LOG_PREFIX + " registerPush failed | " + errCode + " " + errMsg);
        }
    });
  }

  @ReactMethod
  public void registerPushWithOnError(int SDKAppID, String appKey, Callback onSucc, Callback onErr) {
    Log.i(NAME, LOG_PREFIX + " registerPushWithOnError " + SDKAppID + " " + appKey);
    setRunningPlatform();
    TIMPushManager.getInstance().registerPush(mContext, SDKAppID, appKey, new TIMPushCallback() {
        @Override
        public void onSuccess(Object data) {
          onSucc.invoke(data);
          if (data != null) {
            String token = (String)data;
            Log.i(NAME, LOG_PREFIX + " registerPush ok | " + token);
          }
        }
        
        @Override    
        public void onError(int errCode, String errMsg, Object data) { 
          Log.i(NAME, LOG_PREFIX + " registerPush failed | " + errCode + " " + errMsg);
          onErr.invoke(errCode, errMsg);
        }
    });
  }


  @ReactMethod
  public void unRegisterPush(Callback onSucc) {
    Log.i(NAME, LOG_PREFIX + " unRegisterPush");
    TIMPushManager.getInstance().unRegisterPush(new TIMPushCallback() {
      @Override
        public void onSuccess(Object data) {
          Log.i(NAME, LOG_PREFIX + " unRegisterPush ok - ");
          onSucc.invoke();
        }
    });
  }

  @ReactMethod
  public void unRegisterPushWithOnError(Callback onSucc) {
    Log.i(NAME, LOG_PREFIX + " unRegisterPushWithOnError");
    TIMPushManager.getInstance().unRegisterPush(new TIMPushCallback() {
      @Override
      public void onSuccess(Object data) {
        Log.i(NAME, LOG_PREFIX + " unRegisterPushWithOnError ok - ");
        onSucc.invoke();
      }
    });
  }

  @ReactMethod
  public void getRegistrationID(Callback onSucc) {
    TIMPushManager.getInstance().getRegistrationID(new TIMPushCallback() {
      @Override
      public void onSuccess(Object data) {
        if (data != null) {
          String ret = (String)data;
          Log.i(NAME, LOG_PREFIX + " getRegistrationID ok | " + ret);
          onSucc.invoke(ret);
        }
      }
    });
  }

  @ReactMethod
  public void setRegistrationID(String registrationID, Callback onSucc) {
    TIMPushManager.getInstance().setRegistrationID(registrationID, new TIMPushCallback() {
      @Override
      public void onSuccess(Object data) {
        Log.i(NAME, LOG_PREFIX + " setRegistrationID ok");
        onSucc.invoke();
      }
    });
  }

  @ReactMethod
  public void getNotificationExtInfo(Callback onSucc) {
    onSucc.invoke(mExtInfo);
  }

  public void storeExtInfo(String extInfo) {
    Log.i(NAME, LOG_PREFIX = " storeExtInfo | " + extInfo);
    mExtInfo = extInfo;
  }

  private void setRunningPlatform() {
    TIMPushConfig.getInstance().setRunningPlatform(5);
  }
}
